import 'package:flutter/material.dart';

class PhoenixDropdown<T> extends StatelessWidget {
  const PhoenixDropdown({
    Key? key,
    this.isError = false,
    this.errorMessage,
    this.label,
    this.suffixIcon,
    this.onTap,
    required this.value,
    required this.items,
    this.onChanged,
    this.errorTextStyle,
  }) : super(key: key);
  final bool isError;
  final String? errorMessage;
  final String? label;
  final Widget? suffixIcon;
  final VoidCallback? onTap;
  final T value;
  final List<DropdownMenuItem<T>> items;
  final Function(T?)? onChanged;
  final TextStyle? errorTextStyle;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Stack(
          children: [
            Container(
              width: double.maxFinite,
              height: 50,
              decoration: BoxDecoration(
                border: Border.all(
                  color: isError
                      ? const Color(0xffDC3224)
                      : const Color(0xffD9DBE0),
                ),
                borderRadius: BorderRadius.circular(4),
              ),
              alignment: Alignment.topLeft,
              padding: const EdgeInsets.only(bottom: 4),
            ),
            Positioned(
              top: 5,
              left: 0,
              right: 0,
              bottom: 4,
              child: ButtonTheme(
                alignedDropdown: true,
                child: DropdownButtonFormField(
                  isDense: true,
                  isExpanded: true,
                  icon: const SizedBox(),
                  decoration: InputDecoration(
                    contentPadding: const EdgeInsets.only(
                      right: 16,
                      bottom: 4,
                    ),
                    enabledBorder: InputBorder.none,
                    focusedBorder: InputBorder.none,
                    border: InputBorder.none,
                    errorBorder: InputBorder.none,
                    suffixIcon: suffixIcon,
                    label: label != null
                        ? Container(
                            margin: const EdgeInsets.only(
                              top: 6,
                              left: 20,
                            ),
                            child: Text(
                              label ?? "",
                              style: const TextStyle(
                                color: Color(0xFF212124),
                                fontSize: 14,
                                fontWeight: FontWeight.normal,
                              ).copyWith(
                                color: isError
                                    ? const Color(0xffDC3224)
                                    : const Color(0xff75767A),
                              ),
                            ),
                          )
                        : null,
                    alignLabelWithHint: false,
                  ),
                  value: value,
                  items: items,
                  onChanged: onChanged,
                ),
              ),
            ),
            const Positioned(
              top: 0,
              bottom: 0,
              right: 16,
              child: Icon(Icons.keyboard_arrow_down_rounded),
            ),
          ],
        ),
        if (isError && errorMessage!=null)...{
          const SizedBox(height:5),
          Text(
            errorMessage!,
            style: errorTextStyle ?? const TextStyle(
              color: Color(0xffDC3224),
              fontSize: 12,
              fontWeight: FontWeight.normal,
            ),
          ),
        },
        const SizedBox(height: 4),
        const SizedBox(height: 8),
      ],
    );
  }
}
