import 'package:flutter/material.dart';
import 'package:loop_page_view/loop_page_view.dart';

class PhoenixImageEaseOutFade extends StatefulWidget {
  const PhoenixImageEaseOutFade({
    Key? key,
    required this.imageListCollection,
    required this.durationMiliseconds,
    this.imageHeight,
    this.imagePadding,
  }) : super(key: key);

  final List<String> imageListCollection;
  final int durationMiliseconds;
  final EdgeInsets? imagePadding;
  final double? imageHeight;

  @override
  State<PhoenixImageEaseOutFade> createState() =>
      _PhoenixImageEaseOutFadeState();
}

class _PhoenixImageEaseOutFadeState extends State<PhoenixImageEaseOutFade> {
  final LoopPageController _pageController = LoopPageController(
    scrollMode: LoopScrollMode.forwards,
  );
  final LoopPageController _pageController2 = LoopPageController(
    scrollMode: LoopScrollMode.forwards,
    initialPage: 1,
  );
  int _currentPage = 0;
  int _currentPage2 = 1;
  bool visibility = false;
  double opacity = 1.0;
  int numberOfLoops = 0;
  late double imageHeight;
  late int itemCount;

  @override
  void initState() {
    super.initState();
    itemCount = widget.imageListCollection.length;
    _startAutoScroll();
  }

  @override
  void dispose() {
    _pageController.dispose();
    _pageController2.dispose();
    super.dispose();
  }

  Future<void> _startAutoScroll() async {
    if (!mounted) return;
    _handleAnimation();
    Future.delayed(Duration(milliseconds: widget.durationMiliseconds), () {
      if (mounted) {
        setState(() {});
        if (_currentPage == widget.imageListCollection.length - 1) {
          _currentPage = 0;
          numberOfLoops++;
        } else {
          _currentPage++;
        }
        if (_currentPage2 == widget.imageListCollection.length - 1) {
          _currentPage2 = 0;
        } else {
          _currentPage2++;
        }
        _pageController.animateToPage(
          _currentPage,
          duration: Duration(milliseconds: widget.durationMiliseconds),
          curve: Curves.easeOut,
        );
        _pageController2.animateToPage(
          _currentPage2,
          duration: Duration(milliseconds: widget.durationMiliseconds),
          curve: Curves.easeOut,
        );
        _startAutoScroll();
      }
    });
  }

  void _handleAnimation() {
    Future.delayed(Duration(milliseconds: widget.durationMiliseconds ~/ 8), () {
      if (!mounted) return;
      setState(() {
        opacity = 0.0;
      });
    });
    opacity = 1.0;
  }

  @override
  Widget build(BuildContext context) {
    bool isCurrentPage = true;
    imageHeight = widget.imageHeight ??
        ((MediaQuery.of(context).size.width / 16 * 9) / 2);
    final double screenwidth = MediaQuery.of(context).size.width;
    final int imageVisibilityPosition =
        (_currentPage - 1) < 0 && numberOfLoops == 0
            ? 0
            : (_currentPage - 1) % itemCount;
    return Row(
      children: [
        SizedBox(
          height: imageHeight,
          width: screenwidth / 2,
          child: Stack(
            children: [
              Visibility(
                visible: isCurrentPage,
                child: AnimatedOpacity(
                  duration: opacity == 0.0
                      ? Duration(
                          milliseconds: widget.durationMiliseconds ~/ 4,
                        )
                      : Duration.zero,
                  opacity: opacity,
                  child: Container(
                    width: screenwidth / 2,
                    height: imageHeight,
                    padding: widget.imagePadding ?? EdgeInsets.zero,
                    child: Image.network(
                      widget.imageListCollection[imageVisibilityPosition],
                      fit: BoxFit.contain,
                    ),
                  ),
                ),
              ),
              LoopPageView.builder(
                controller: _pageController,
                onPageChanged: (index) {},
                itemCount: itemCount,
                physics: const NeverScrollableScrollPhysics(),
                itemBuilder: (context, index) {
                  final currentIndex = index % itemCount;
                  isCurrentPage = currentIndex == _currentPage ||
                      currentIndex == _currentPage % itemCount;
                  return Visibility(
                    visible: isCurrentPage,
                    child: ListView(
                      scrollDirection: Axis.horizontal,
                      children: [
                        for (int i = currentIndex; i <= currentIndex + 1; i++)
                          Container(
                            width: screenwidth / 2,
                            height: imageHeight,
                            padding: widget.imagePadding ?? EdgeInsets.zero,
                            child: Image.network(
                              widget.imageListCollection[i % itemCount],
                              fit: BoxFit.contain,
                            ),
                          ),
                      ],
                    ),
                  );
                },
              ),
            ],
          ),
        ),
        SizedBox(
          height: imageHeight,
          width: screenwidth / 2,
          child: LoopPageView.builder(
            controller: _pageController2,
            onPageChanged: (index) {},
            physics: const NeverScrollableScrollPhysics(),
            itemCount: itemCount,
            itemBuilder: (context, index) {
              final currentIndex = index % itemCount;
              return ListView(
                scrollDirection: Axis.horizontal,
                children: [
                  for (int i = currentIndex; i <= currentIndex + 1; i++)
                    Container(
                      width: screenwidth / 2,
                      height: imageHeight,
                      padding: widget.imagePadding ?? EdgeInsets.zero,
                      child: Image.network(
                        widget.imageListCollection[i % itemCount],
                        fit: BoxFit.contain,
                      ),
                    ),
                ],
              );
            },
          ),
        ),
      ],
    );
  }
}
